===============================
finchan
===============================


.. image:: https://img.shields.io/pypi/v/finchan.svg
        :target: https://pypi.python.org/pypi/finchan

.. image:: https://img.shields.io/travis/qytz/finchan.svg
        :target: https://travis-ci.org/qytz/finchan

.. image:: https://readthedocs.org/projects/finchan/badge/?version=latest
        :target: https://finchan.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/qytz/finchan/shield.svg
     :target: https://pyup.io/repos/github/qytz/finchan/
     :alt: Updates


Finchan event process framework with python.


* Free software: Apache License 2.0
* Documentation: https://finchan.readthedocs.io.


Features
--------

Do whatever you want with it.

* Event-driven
* Support live trace and backtrack test
* Easy extensionable
* Support Python 3.6+
* Does not support Python 2.x
